@@ -19,7 +19,6 @@ test_that("Error handling", {
 
 test_that("Query 'Melbourne Airport' returns data frame w/ correct station", {
   skip_on_cran()
-  get_current_weather("Sydney")
   YMML <- get_current_weather("Melbourne Airport")
   expect_is(YMML, "bomrang_tbl")
   expect_equal(YMML$full_name[1], "Melbourne Airport")
@@ -27,18 +26,12 @@ test_that("Query 'Melbourne Airport' returns data frame w/ correct station", {
 
 test_that("Query of 'Sydney' defaults to Observatory Hill", {
   skip_on_cran()
-  get_current_weather("Sydney")
   expect_warning(get_current_weather("Sydney"),
                  regexp = "Multiple stations match")
   SYD <- suppressWarnings(get_current_weather("Sydney"))
   expect_equal(unique(SYD$full_name), "Sydney - Observatory Hill")
 })
 
-# test_that("Query of 'castlem' and friends", {
-#   skip_on_cran()
-#   expect_error(get_current_weather(station_name = "castlem"))
-# })
-
 test_that("Strict", {
   skip_on_cran()
   expect_error(get_current_weather("Melbourne", strict = TRUE),
