@@ -18,7 +18,7 @@ test_that("get_available_radar functions properly", {
   expect_gt(nrow(xx), 0)
   expect_equal(xx, get_available_radar(radar_id = "all"))
 
-  xxx <- get_available_radar(radar_id = "3")
+  xxx <- get_available_radar(radar_id = 3)
   expect_is(xxx, "data.frame")
   expect_gt(nrow(xxx), 0)
   expect_lt(nrow(xxx), 5)
@@ -38,7 +38,7 @@ test_that("Error handling works", {
 test_that("get_radar_imagery functions properly", {
   skip_on_cran()
   y <- get_radar_imagery(product_id = "IDR022")
-  expect_is(y, "RasterLayer")
+  expect_is(y, "magick-image")
 
   yy <- get_radar_imagery(product_id = "IDR022", download_only = TRUE)
   expect_null(yy)
